@@ -28,5 +28,6 @@
 #endif
 
 gint bluetooth_init(guint service, const gchar *name, const gchar *folder,
-			guint8 channel, gboolean secure, gboolean auto_accept);
+			guint8 channel, gboolean secure, gboolean auto_accept,
+			const gchar *capability);
 void bluetooth_exit(void);
